@@ -10,4 +10,7 @@ class BackendBase:
     
     def get(self, filename, bucket, bucket_name):
         pass
+    
+    def geturl(self, entrypoint):
+        return entrypoint
     
\ No newline at end of file
