@@ -27,13 +27,13 @@ except:
 
 class Client(Singleton):
     @staticmethod
-    def get_client(host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None):
-        client = Client(host, redis_client, mq_manager, async_mq_mode)
+    def get_client(host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=True):
+        client = Client(host, redis_client, mq_manager, async_mq_mode, init_redis=init_redis)
         return client
     
-    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None) -> None:
+    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=init_redis) -> None:
         self.host = host
-        if redis_client is None:
+        if redis_client is None and init_redis:
             redis_client = XRedis(REDIS['host'], REDIS['pass'], REDIS['port'], REDIS['db'])
         self.redis = redis_client
         
